==> DateTime-Locale-1.42.tar.gz: DateTime-Locale-1.42/share/sr-Latn-XK.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "hh:mm B",
    Bhms => "hh:mm:ss B",
    E => "E",
    EBhm => "E hh:mm B",
    EBhms => "E hh:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y. G",
    GyMMM => "MMM y. G",
    GyMMMEd => "E, d. MMM y. G",
    GyMMMd => "d. MMM y. G",
    GyMd => "d.MM.y. GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d. M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-few" => "W. 'sedmica' 'u' MMMM.",
    "MMMMW-count-one" => "W. 'sedmica' 'u' MMMM.",
    "MMMMW-count-other" => "W. 'sedmica' 'u' MMMM.",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMMdd => "dd.MMM",
    MMdd => "dd.MM.",
    Md => "d. M.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y.",
    yM => "M. y.",
    yMEd => "E, d. M. y.",
    yMM => "MM.y.",
    yMMM => "MMM y.",
    yMMMEd => "E, d. MMM y.",
    yMMMM => "MMMM y.",
    yMMMd => "d. MMM y.",
    yMMdd => "dd.MM.y.",
    yMd => "d. M. y.",
    yQQQ => "QQQ y.",
    yQQQQ => "QQQQ y.",
    "yw-count-few" => "w. 'sedmica' 'u' Y.",
    "yw-count-one" => "w. 'sedmica' 'u' Y.",
    "yw-count-other" => "w. 'sedmica' 'u' Y.",
  },
  code => "sr-Latn-XK",
  date_format_full => "EEEE, d. MMMM y.",
  date_format_long => "d. MMMM y.",
  date_format_medium => "d. M. y.",
  date_format_short => "d.M.yy.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pon",
    "uto",
    "sre",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_format_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "ponedeljak",
    "utorak",
    "sreda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedelja",
  ],
  day_stand_alone_abbreviated => [
    "pon",
    "uto",
    "sre",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_stand_alone_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "ponedeljak",
    "utorak",
    "sreda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedelja",
  ],
  era_abbreviated => [
    "p. n. e.",
    "n. e.",
  ],
  era_narrow => [
    "p.n.e.",
    "n.e.",
  ],
  era_wide => [
    "pre nove ere",
    "nove ere",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Serbian",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mart",
    "apr",
    "maj",
    "jun",
    "jul",
    "avg",
    "sept",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "jun",
    "jul",
    "avgust",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mart",
    "apr",
    "maj",
    "jun",
    "jul",
    "avg",
    "sept",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "jun",
    "jul",
    "avgust",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  name => "Serbian Kosovo Latin",
  native_language => "srpski",
  native_name => "srpski Kosovo latinica",
  native_script => "latinica",
  native_territory => "Kosovo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. kv.",
    "2. kv.",
    "3. kv.",
    "4. kv.",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "prvi kvartal",
    "drugi kvartal",
    "tre\N{U+0107}i kvartal",
    "\N{U+010d}etvrti kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "1. kv.",
    "2. kv.",
    "3. kv.",
    "4. kv.",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "prvi kvartal",
    "drugi kvartal",
    "tre\N{U+0107}i kvartal",
    "\N{U+010d}etvrti kvartal",
  ],
  script => "Latin",
  territory => "Kosovo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 45,
}

==> DateTime-Locale-1.45.tar.gz: DateTime-Locale-1.45/share/sr-Latn-XK.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "hh:mm B",
    Bhms => "hh:mm:ss B",
    E => "E",
    EBhm => "E h:mm B",
    EBhms => "E, hh:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y. G",
    GyMMM => "MMM y. G",
    GyMMMEd => "E, d. MMM y. G",
    GyMMMd => "d. MMM y. G",
    GyMd => "d.MM.y. GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d. M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E, d. MMMM",
    "MMMMW-count-few" => "MMMM: W. 'nedelja'",
    "MMMMW-count-one" => "MMMM: W. 'nedelja'",
    "MMMMW-count-other" => "MMMM: W. 'nedelja'",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMMdd => "dd.MMM",
    MMdd => "dd.MM.",
    Md => "d. M.",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y.",
    yM => "M. y.",
    yMEd => "E, d. M. y.",
    yMM => "MM.y.",
    yMMM => "MMM y.",
    yMMMEd => "E, d. MMM y.",
    yMMMM => "MMMM y.",
    yMMMd => "d. MMM y.",
    yMMdd => "dd.MM.y.",
    yMd => "d. M. y.",
    yQQQ => "QQQ y.",
    yQQQQ => "QQQQ y.",
    "yw-count-few" => "w. 'nedelja' 'u' Y.",
    "yw-count-one" => "w. 'nedelja' 'u' Y.",
    "yw-count-other" => "w. 'nedelja' 'u' Y.",
  },
  code => "sr-Latn-XK",
  date_format_full => "EEEE, d. MMMM y.",
  date_format_long => "d. MMMM y.",
  date_format_medium => "d. M. y.",
  date_format_short => "d. M. y.",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "pon",
    "uto",
    "sre",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_format_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_format_wide => [
    "ponedeljak",
    "utorak",
    "sreda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedelja",
  ],
  day_stand_alone_abbreviated => [
    "pon",
    "uto",
    "sre",
    "\N{U+010d}et",
    "pet",
    "sub",
    "ned",
  ],
  day_stand_alone_narrow => [
    "p",
    "u",
    "s",
    "\N{U+010d}",
    "p",
    "s",
    "n",
  ],
  day_stand_alone_wide => [
    "ponedeljak",
    "utorak",
    "sreda",
    "\N{U+010d}etvrtak",
    "petak",
    "subota",
    "nedelja",
  ],
  era_abbreviated => [
    "p. n. e.",
    "n. e.",
  ],
  era_narrow => [
    "p.n.e.",
    "n.e.",
  ],
  era_wide => [
    "pre nove ere",
    "nove ere",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Serbian",
  month_format_abbreviated => [
    "jan",
    "feb",
    "mart",
    "apr",
    "maj",
    "jun",
    "jul",
    "avg",
    "sept",
    "okt",
    "nov",
    "dec",
  ],
  month_format_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "jun",
    "jul",
    "avgust",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mart",
    "apr",
    "maj",
    "jun",
    "jul",
    "avg",
    "sept",
    "okt",
    "nov",
    "dec",
  ],
  month_stand_alone_narrow => [
    "j",
    "f",
    "m",
    "a",
    "m",
    "j",
    "j",
    "a",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mart",
    "april",
    "maj",
    "jun",
    "jul",
    "avgust",
    "septembar",
    "oktobar",
    "novembar",
    "decembar",
  ],
  name => "Serbian Kosovo Latin",
  native_language => "srpski",
  native_name => "srpski Kosovo latinica",
  native_script => "latinica",
  native_territory => "Kosovo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. kv.",
    "2. kv.",
    "3. kv.",
    "4. kv.",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "prvi kvartal",
    "drugi kvartal",
    "tre\N{U+0107}i kvartal",
    "\N{U+010d}etvrti kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "1. kv.",
    "2. kv.",
    "3. kv.",
    "4. kv.",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "prvi kvartal",
    "drugi kvartal",
    "tre\N{U+0107}i kvartal",
    "\N{U+010d}etvrti kvartal",
  ],
  script => "Latin",
  territory => "Kosovo",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 47,
}
